# The profile to install the Glance API and Registry services
# Note that for this configuration API controls the storage,
# so it is on the storage node instead of the control node
class openstack::profile::glance::api {
  $api_network = $::openstack::config::network_api
  $api_address = ip_for_network($api_network)
  $bind_host = $::openstack::config::bind_host

  $management_network = $::openstack::config::network_management
  $management_address = ip_for_network($management_network)

  $explicit_management_address = $::openstack::config::storage_address_management
  $explicit_api_address = $::openstack::config::storage_address_api

  $controller_address = $::openstack::config::controller_address_management


  openstack::resources::firewall { 'Glance API': port      => '9292', }
  openstack::resources::firewall { 'Glance Registry': port => '9191', }

  include ::openstack::common::glance

  class { '::glance::backend::file': }

  class { '::glance::registry':
    bind_host           => $bind_host,
    keystone_password   => $::openstack::config::glance_password,
    database_connection => $::openstack::resources::connectors::glance,
    auth_host           => $::openstack::config::controller_address_management,
    keystone_tenant     => 'services',
    keystone_user       => 'glance',
    verbose             => $::openstack::config::verbose,
    debug               => $::openstack::config::debug,
    mysql_module        => '2.2',
  }

  class { '::glance::notify::rabbitmq':
    rabbit_password => $::openstack::config::rabbitmq_password,
    rabbit_userid   => $::openstack::config::rabbitmq_user,
    rabbit_hosts     => $::openstack::config::rabbitmq_hosts,
  }
}
