class openstack::profile::ha{

  $keystone_public_port=5000
  $keystone_admin_port=35357
  $mysql_port=3306
  $glance_api_port=9292
  $glance_registry_port=9191
  $cinder_port=8776
  $nova_port=8774
  $novnc_port=6080
  $neutron_port=9696
  $memcache_port=11211
  $horizon_port=80
  $swift_port=8080

  $hosts_vip  = $::openstack::config::controller_address_api
  $cluster_hosts = $::openstack::config::controller_cluster_hosts
  $cluster_hosts_ip = $::openstack::config::controller_cluster_hosts_ip
  $interface = $::openstack::config::bind_host

  sysctl { 'net.ipv4.ip_nonlocal_bind': val => '1' }~>
  sysctl { 'net.ipv4.ip_forward': val => '1' }~>

  exec {'sysctl':
    command => "/sbin/sysctl -p",
    logoutput => true,
  }
  if $hostname == 'mycloud' {
      $priority     = 101
  }
  else
  {
      $priority = 100
  }

  include keepalived
  keepalived::vrrp::script {'check_haproxy':
    script => '/usr/bin/killall -0 haproxy',
  }

  keepalived::vrrp::instance { 'VI_50':
    interface         => $interface,
    state             => 'MASTER',
    virtual_router_id => '50',
    priority          => $priority,
    auth_type         => 'PASS',
    auth_pass         => 'secret',
    virtual_ipaddress => [ $hosts_vip ],
    track_interface   => [$interface], # optional, monitor these interfaces.
    track_script      => 'check_haproxy',
  }~>

  class { 'haproxy':
     require => Class['keepalived'],
  }
 
  haproxy::listen { 'mysql_cluster':
    ipaddress => $hosts_vip,
    ports     => $mysql_port,
    mode      => 'tcp',		
    options   => {
      'option'  => [ 'httpchk'],
      'balance' => 'roundrobin'
    }
  }
  haproxy::balancermember { 'mysql_cluster_hosts':
    listening_service => 'mysql_cluster',
    ports             => $mysql_port,
    server_names      => $cluster_hosts,
    ipaddresses       => $cluster_hosts_ip,
    options           => 'check port 9200 inter 2000 rise 2 fall 5',
  }

  haproxy::listen { 'horizon_cluster':
    ipaddress => $hosts_vip,
    ports     => $horizon_port,
    mode      => 'http',
    options   => {
      'option'  => ['tcpka', 'httpchk', 'tcplog'],
      'balance' => 'source'
    }
  }
  haproxy::balancermember { 'horizon_cluster_hosts':
    listening_service => 'horizon_cluster',
    ports             => $horizon_port,
    server_names      => $cluster_hosts,
    ipaddresses       => $cluster_hosts_ip,
    options           => 'check inter 2000 rise 2 fall 5',
  }
  haproxy::listen { 'keystone_admin_cluster':
    ipaddress => $hosts_vip,
    ports     => $keystone_admin_port,
    mode      => 'http',
    options   => {
      'option'  => ['tcpka', 'httpchk', 'tcplog'],
      'balance' => 'source'
    }
  }
  haproxy::balancermember { 'keystone_cluster_hosts':
    listening_service => 'keystone_admin_cluster',
    ports             => $keystone_admin_port,
    server_names      => $cluster_hosts,
    ipaddresses       => $cluster_hosts_ip,
    options           => 'check inter 2000 rise 2 fall 5',
  }
  haproxy::listen { 'keystone_public_cluster':
    ipaddress => $hosts_vip,
    ports     => $keystone_public_port,
    mode      => 'http',
    options   => {
      'option'  => ['tcpka', 'httpchk', 'tcplog'],
      'balance' => 'source'
    }
  }
  haproxy::balancermember { 'keystone_cluster_hosts_internal':
    listening_service => 'keystone_public_cluster',
    ports             => $keystone_public_port,
    server_names      => $cluster_hosts,
    ipaddresses       => $cluster_hosts_ip,
    options           => 'check inter 2000 rise 2 fall 5',
  }
  haproxy::listen { 'memcache_cluster':
    ipaddress => $hosts_vip,
    ports     => $memcache_port,
    mode      => 'http',
    options   => {
      'option'  => ['tcpka', 'httpchk', 'tcplog'],
      'balance' => 'source'
    }
  }
  haproxy::balancermember { 'memcache_cluster_hosts':
    listening_service => 'memcache_cluster',
    ports             => $memcache_port,
    server_names      => $cluster_hosts,
    ipaddresses       => $cluster_hosts_ip,
    options           => 'check inter 2000 rise 2 fall 5',
  }~>
  haproxy::listen { 'nova_cluster':
    ipaddress => $hosts_vip,
    ports     => $nova_port,
    mode      => 'http',
    options   => {
      'option'  => ['tcpka', 'httpchk', 'tcplog'],
      'balance' => 'source'
    }
  }
  haproxy::balancermember { 'nova_cluster_hosts':
    listening_service => 'nova_cluster',
    ports             => $nova_port,
    server_names      => $cluster_hosts,
    ipaddresses       => $cluster_hosts_ip,
    options           => 'check inter 2000 rise 2 fall 5',
  }
  haproxy::listen { 'novnc_cluster':
    ipaddress => $hosts_vip,
    ports     => $novnc_port,
    mode      => 'http',
    options   => {
      'option'  => ['tcpka', 'httpchk', 'tcplog'],
      'balance' => 'source'
    }
  }
  haproxy::balancermember { 'novnc_cluster_hosts':
    listening_service => 'novnc_cluster',
    ports             => $novnc_port,
    server_names      => $cluster_hosts,
    ipaddresses       => $cluster_hosts_ip,
    options           => 'check inter 2000 rise 2 fall 5',
  }
  haproxy::listen { 'neutron_cluster':
    ipaddress => $hosts_vip,
    ports     => $neutron_port,
    mode      => 'http',
    options   => {
      'option'  => ['tcpka', 'httpchk', 'tcplog'],
      'balance' => 'source'
    }
  }
  haproxy::balancermember { 'neutron_cluster_hosts':
    listening_service => 'neutron_cluster',
    ports             => $neutron_port,
    server_names      => $cluster_hosts,
    ipaddresses       => $cluster_hosts_ip,
    options           => 'check inter 2000 rise 2 fall 5',
  }
  haproxy::listen { 'cinder_cluster':
    ipaddress => $hosts_vip,
    ports     => $cinder_port,
    mode      => 'http',
    options   => {
      'option'  => ['tcpka', 'httpchk', 'tcplog'],
      'balance' => 'source'
    }
  }
  haproxy::balancermember { 'cinder_cluster_hosts':
    listening_service => 'cinder_cluster',
    ports             => $cinder_port,
    server_names      => $cluster_hosts,
    ipaddresses       => $cluster_hosts_ip,
    options           => 'check inter 2000 rise 2 fall 5',
  }
  haproxy::listen { 'swift_proxy_cluster':
    ipaddress => $hosts_vip,
    ports     => $swift_port,
    mode      => 'http',
    options   => {
      'option'  => ['tcpka', 'httpchk', 'tcplog'],
      'balance' => 'source'
    }
  }
  haproxy::balancermember { 'swift_proxy_cluster_hosts':
    listening_service => 'swift_proxy_cluster',
    ports             => $swift_port,
    server_names      => $cluster_hosts,
    ipaddresses       => $cluster_hosts_ip,
    options           => 'check inter 2000 rise 2 fall 5',
  }
  haproxy::listen { 'glance_api_cluster':
    ipaddress => $hosts_vip,
    ports     => $glance_api_port,
    mode      => 'http',
    options   => {
      'option'  => ['tcpka', 'httpchk', 'tcplog'],
      'balance' => 'source'
    }
  }
  haproxy::balancermember { 'glance_api_cluster_hosts':
    listening_service => 'glance_api_cluster',
    ports             => $glance_api_port,
    server_names      => $cluster_hosts,
    ipaddresses       => $cluster_hosts_ip,
    options           => 'check inter 2000 rise 2 fall 5',
  }
  haproxy::listen { 'glance_registry_cluster':
    ipaddress => $hosts_vip,
    ports     => $glance_registry_port,
    mode      => 'http',
    options   => {
      'option'  => ['tcpka', 'httpchk', 'tcplog'],
      'balance' => 'source'
    }
  }
  haproxy::balancermember { 'glance_registry_cluster_hosts':
    listening_service => 'glance_registry_cluster',
    ports             => $glance_registry_port,
    server_names      => $cluster_hosts,
    ipaddresses       => $cluster_hosts_ip,
    options           => 'check inter 2000 rise 2 fall 5',
  }
}

